@@ -1,13 +1,13 @@
 from typing import Union
 
+from ._tuple import JSFTuple
 from .array import Array
-from .number import Number, Integer
+from .boolean import Boolean
+from .enum import JSFEnum
+from .null import Null
+from .number import Integer, Number
 from .object import Object
 from .string import String
-from ._tuple import Tuple
-from .enum import Enum
-from .null import Null
-from .boolean import Boolean
 
 Primitives = {
     "number": Number,
@@ -18,5 +18,5 @@ Primitives = {
     "null": Null,
 }
 
-AllTypes = Union[Enum, Object, Array, Tuple, String, Boolean, Null, Number, Integer]
+AllTypes = Union[JSFEnum, Object, Array, JSFTuple, String, Boolean, Null, Number, Integer]
 PrimativeTypes = Union[String, Boolean, Null, Number, Integer]
