@@ -1,20 +1,22 @@
+import logging
 import random
-from dataclasses import dataclass
-from typing import Optional, Dict, Union, List, Any
+from typing import Any, Dict, List, Optional, Union
+
+from pydantic import BaseModel, create_model
 
 from .base import BaseSchema, ProviderNotSetException
 
+logger = logging.getLogger()
 
-@dataclass
-class PropertyNames:
-    pattern: Optional[str]
+
+class PropertyNames(BaseModel):
+    pattern: Optional[str] = None
 
 
 PropertyDependency = Dict[str, List[str]]
 SchemaDependency = Dict[str, "Object"]
 
 
-@dataclass
 class Object(BaseSchema):
     properties: Dict[str, BaseSchema] = None
     additionalProperties: Optional[Union[bool, BaseSchema]] = None
@@ -25,13 +27,26 @@ class Object(BaseSchema):
     dependencies: Optional[Union[PropertyDependency, SchemaDependency]] = None
     patternProperties: Optional[Dict[str, BaseSchema]] = None
 
+    def from_dict(d):
+        print(d)
+        return Object(**d)
+
     def should_keep(self, property_name: str) -> bool:
         if isinstance(self.required, list) and property_name in self.required:
             return True
         return random.uniform(0, 1) < 0.5
 
-    def generate(self, state: Dict[str, Any]) -> Optional[Dict[str, Any]]:
+    def generate(self, context: Dict[str, Any]) -> Optional[Dict[str, Any]]:
         try:
-            return super().generate(state)
+            return super().generate(context)
         except ProviderNotSetException:
-            return {o.name: o.generate(state) for o in self.properties if self.should_keep(o.name)}
+            return {o.name: o.generate(context) for o in self.properties if self.should_keep(o.name)}
+
+    def model(self, context: Dict[str, Any]):
+        self.generate(context)
+        _type = create_model("Object", **{o.name: o.model(context) for o in self.properties})
+        context["__internal__"][_type.__name__] = _type
+        return self.to_pydantic(context, _type)
+
+
+Object.update_forward_refs()
